@@ -4,7 +4,7 @@
 import typing as t
 
 from .parser import DDDiceRollerParser
-from .roller import DiceRoll
+from .class_roller import DiceRoll
 
 args = DDDiceRollerParser().args
 try:
